@@ -146,7 +146,7 @@ static bool is_pkcs11_uri(const char *string)
  *
  */
 static curl_off_t vms_realfilesize(const char *name,
-                                   const curl_struct_stat *stat_buf)
+                                   const curlx_struct_stat *stat_buf)
 {
   char buffer[8192];
   curl_off_t count;
@@ -177,7 +177,7 @@ static curl_off_t vms_realfilesize(const char *name,
  *
  */
 static curl_off_t VmsSpecialSize(const char *name,
-                                 const curl_struct_stat *stat_buf)
+                                 const curlx_struct_stat *stat_buf)
 {
   switch(stat_buf->st_fab_rfm) {
   case FAB$C_VAR:
@@ -248,7 +248,7 @@ static struct per_transfer *del_per_transfer(struct per_transfer *per)
 static CURLcode pre_transfer(struct per_transfer *per)
 {
   curl_off_t uploadfilesize = -1;
-  curl_struct_stat fileinfo;
+  curlx_struct_stat fileinfo;
   CURLcode result = CURLE_OK;
 
   if(per->uploadfile && !stdin_upload(per->uploadfile)) {
@@ -548,7 +548,7 @@ static CURLcode retrycheck(struct OperationConfig *config,
     }
 
     if(truncate && outs->bytes && outs->filename && outs->stream) {
-      curl_struct_stat fileinfo;
+      curlx_struct_stat fileinfo;
 
       /* The output can be a named pipe or a character device etc that
          cannot be truncated. Only truncate regular files. */
@@ -718,7 +718,7 @@ static CURLcode post_per_transfer(struct per_transfer *per,
       errorf("curl: (%d) Failed writing body", result);
     }
     if(result && config->rm_partial) {
-      curl_struct_stat st;
+      curlx_struct_stat st;
       if(!curlx_stat(outs->filename, &st) && S_ISREG(st.st_mode)) {
         if(!unlink(outs->filename))
           notef("Removed output file: %s", outs->filename);
@@ -910,7 +910,7 @@ static CURLcode etag_store(struct OperationConfig *config,
   }
   else {
     /* always use binary mode for protocol header output */
-    CURLX_SET_BINMODE(etag_save->stream);
+    CURL_BINMODE(etag_save->stream);
   }
   return CURLE_OK;
 }
@@ -923,7 +923,7 @@ static CURLcode setup_headerfile(struct OperationConfig *config,
   if(!strcmp(config->headerfile, "%")) {
     heads->stream = stderr;
     /* use binary mode for protocol header output */
-    CURLX_SET_BINMODE(heads->stream);
+    CURL_BINMODE(heads->stream);
   }
   else if(strcmp(config->headerfile, "-")) {
     FILE *newfile;
@@ -963,7 +963,7 @@ static CURLcode setup_headerfile(struct OperationConfig *config,
   }
   else {
     /* always use binary mode for protocol header output */
-    CURLX_SET_BINMODE(heads->stream);
+    CURL_BINMODE(heads->stream);
   }
   return CURLE_OK;
 }
@@ -1040,7 +1040,7 @@ static CURLcode setup_outfile(struct OperationConfig *config,
   }
 
   if(config->skip_existing) {
-    curl_struct_stat fileinfo;
+    curlx_struct_stat fileinfo;
     if(!curlx_stat(per->outfile, &fileinfo)) {
       /* file is present */
       notef("skips transfer, \"%s\" exists locally", per->outfile);
@@ -1052,7 +1052,7 @@ static CURLcode setup_outfile(struct OperationConfig *config,
   if(config->resume_from_current) {
     /* We are told to continue from where we are now. Get the size
        of the file as it is now and open it for append instead */
-    curl_struct_stat fileinfo;
+    curlx_struct_stat fileinfo;
     /* VMS -- Danger, the filesize is only valid for stream files */
     if(curlx_stat(per->outfile, &fileinfo) == 0)
       /* set offset to current file size: */
@@ -1118,7 +1118,7 @@ static void check_stdin_upload(struct OperationConfig *config,
   DEBUGASSERT(per->infdopen == FALSE);
   DEBUGASSERT(per->infd == STDIN_FILENO);
 
-  CURLX_SET_BINMODE(stdin);
+  CURL_BINMODE(stdin);
   if(!strcmp(per->uploadfile, ".")) {
 #if defined(USE_WINSOCK) && !defined(CURL_WINDOWS_UWP)
     /* non-blocking stdin behavior on Windows is challenging
@@ -1350,7 +1350,7 @@ static CURLcode create_single(struct OperationConfig *config,
        !config->use_ascii) {
       /* We get the output to stdout and we have not got the ASCII/text flag,
          then set stdout to be binary */
-      CURLX_SET_BINMODE(stdout);
+      CURL_BINMODE(stdout);
     }
 
     /* explicitly passed to stdout means okaying binary gunk */
